@@ -2,11 +2,16 @@
 { 736886784UL, 737411071UL, "whois.apnic.net" },
 { 737476608UL, 738000895UL, "whois.apnic.net" },
 { 738066432UL, 738197503UL, "whois.apnic.net" },
+{ 756023296UL, 757071871UL, "whois.arin.net" },
 { 757071872UL, 759169023UL, "whois.arin.net" },
 { 759169024UL, 759238655UL, "whois.apnic.net" },
+{ 760217600UL, 761266175UL, "whois.ripe.net" },
+{ 761266176UL, 762314751UL, "whois.afrinic.net" },
+{ 762314752UL, 763363327UL, "whois.apnic.net" },
 { 763363328UL, 765460479UL, "whois.ripe.net" },
 { 765460480UL, 767557631UL, "whois.lacnic.net" },
 { 767557632UL, 769589247UL, "whois.afrinic.net" },
+{ 769654784UL, 770703359UL, "whois.lacnic.net" },
 { 2523594752UL, 2523660287UL, "whois.apnic.net" },
 { 2525036544UL, 2525102079UL, "whois.apnic.net" },
 { 2532442112UL, 2532507647UL, "whois.apnic.net" },
